@@ -18,7 +18,7 @@ from .exceptions import (
     UnauthorizedError,
     UnknownError,
 )
-from .models import CamelModel
+from .models import CamelModel, FileDownloadRef
 from .responses import UJSONResponse
 from .utils import (
     async_get,
