@@ -3,6 +3,9 @@ from typing import Any, List, Optional, Tuple, Type
 from google.cloud.exceptions import NotFound
 from google.cloud.firestore import Client, CollectionReference, Query
 
+from fa_common import DatabaseError, force_async, get_current_app
+from fa_common import logger as LOG
+
 from .base_client import BaseClient
 from .models import (
     DBIndex,
@@ -13,7 +16,6 @@ from .models import (
     WhereCondition,
     WriteResult,
 )
-from fa_common import force_async, get_current_app, logger as LOG, DatabaseError
 
 
 class FirestoreClient(BaseClient):
@@ -94,21 +96,22 @@ class FirestoreClient(BaseClient):
         await force_async(collection.document(_id).update)(data)
         return WriteResult()
 
-    async def update_many(
-        self, model: Type[DocumentDBModel], data: List[Tuple[str, dict]]
-    ) -> WriteResult:
+    # FIXME: Intended to update all docs that meet search criteria with a single set of values
+    # async def update_many(
+    #     self, model: Type[DocumentDBModel], data: List[Tuple[str, dict]]
+    # ) -> WriteResult:
 
-        collection_name = model.get_db_collection()
-        collection = self.get_collection(collection_name)
+    #     collection_name = model.get_db_collection()
+    #     collection = self.get_collection(collection_name)
 
-        batch = self.firestore.batch()
-        for _id, _data in data:
-            doc_ref = collection.document(_id)
+    #     batch = self.firestore.batch()
+    #     for _id, _data in data:
+    #         doc_ref = collection.document(_id)
 
-            batch.update(doc_ref, field_updates=_data)
-        await force_async(batch.commit)()
+    #         batch.update(doc_ref, field_updates=_data)
+    #     await force_async(batch.commit)()
 
-        return WriteResult()
+    #     return WriteResult()
 
     async def get(
         self, model: Type[DocumentDBModel], _id: str, session: Any = None
